@@ -1,5 +1,5 @@
 pirls.per.pv <- 
-  function(pvlabel="ASRREA", by, per, data, export=FALSE, name= "output", folder=getwd()) {
+  function(pvlabel, by, per, data, export=FALSE, name= "output", folder=getwd()) {
     
     intsvy.per.pv(pvnames = pvlabel, per=per, by=by, data=data, export=export, 
                   name= name, folder=folder, config=pirls_conf)
