@@ -1,5 +1,5 @@
 pisa.log.pv <- 
-  function(pvlabel="READ", x, by, cutoff, data, export=FALSE, 
+  function(pvlabel, x, by, cutoff, data, export=FALSE, 
            name= "output", folder=getwd()) {
     
   intsvy.log.pv(x=x, pvnames = pvlabel, cutoff=cutoff, by=by, data=data, export=export, 
