@@ -1,5 +1,5 @@
 timss.log.pv <- 
-  function(pvlabel="BSMMAT", x, by, cutoff, data, 
+  function(pvlabel, x, by, cutoff, data, 
            export=FALSE, name= "output", folder=getwd()) {
     
   intsvy.log.pv(x=x, pvnames = pvlabel, cutoff=cutoff, by=by, data=data, export=export, 
