@@ -1,5 +1,5 @@
 timss.per.pv <- 
-  function(pvlabel="BSMMAT", by, per, data, export=FALSE, name= "output", folder=getwd()) {
+  function(pvlabel, by, per, data, export=FALSE, name= "output", folder=getwd()) {
     
     intsvy.per.pv(pvnames = pvlabel, by=by, per=per, data=data, export=export, 
                   name= name, folder=folder, config=timss8_conf)
