@@ -1,5 +1,5 @@
 timss.reg.pv <-
-  function(x, pvlabel="BSMMAT",  by, data, std=FALSE, export=FALSE, name= "output", folder=getwd()) {
+  function(x, pvlabel,  by, data, std=FALSE, export=FALSE, name= "output", folder=getwd()) {
     
     intsvy.reg.pv(x=x, pvnames = pvlabel, by=by, data=data, std=std, export=export, 
                   name= name, folder=folder, config=timss8_conf) 
